@@ -95,7 +95,10 @@ def test_query_invalid_series(jsoc_client):
 
 
 @pytest.mark.remote_data
-def test_query_hexadecimal_strings():
+@pytest.mark.parametrize(
+    "query", ["hmi.v_45s[2014.01.01_00:00:35_TAI-2014.01.01_01:00:35_TAI]", "hmi.M_720s[2011.04.14_00:30:00_TAI/6h@2h]"]
+)
+def test_query_hexadecimal_strings(query):
     # Exercise the part of client.py that deals with hexadecimal strings
     c = drms.Client()
-    c.query("hmi.v_45s[2014.01.01_00:00:35_TAI-2014.01.01_01:00:35_TAI]", key="**ALL**")
+    c.query(query, key="**ALL**")
